Demo page

### Checkboxes

Option one Option two Option three Option four

### Radio buttons

Strawberry Banana Raspberry

### Buttons outside of .pat-checklist element

The buttons to select or deselect the checklist may lie outside of the .pat-checklist element. However, to avoid mismatches, the selectors then need to be disambiguated by starting with an object id. In other words, the selector needs to start with #elementId.

Option one Option two Option three Option four